@@ -4,12 +4,12 @@
 ;; Copyright (C) 2022  Campbell Barton  <ideasman42@gmail.com>
 ;; Copyright (C) 2013-2015, Friedrich Paetzke <f.paetzke@gmail.com>
 
-;; Author: Friedrich Paetzk <f.paetzke@gmail.com>
-
+;; Author: Friedrich Paetzke <f.paetzke@gmail.com>
+;; Maintainer: Campbell Barton <ideasman42@gmail.com>
 ;; URL: https://codeberg.org/ideasman42/emacs-py-autopep8
 ;; Keywords: convenience
-;; Package-Version: 20251126.1135
-;; Package-Revision: 4582cf1e1f4e
+;; Package-Version: 20260108.1346
+;; Package-Revision: f07d487a6cd6
 ;; Package-Requires: ((emacs "29.1"))
 
 ;;; Commentary:
@@ -17,7 +17,7 @@
 ;; Provides the `py-autopep8-buffer' command, which uses the external "autopep8"
 ;; tool to tidy up the current buffer according to Python's PEP8.
 
-;;; Usage
+;;; Usage:
 
 ;;
 ;; To automatically apply when saving a python file, use the
@@ -65,7 +65,8 @@
 (defcustom py-autopep8-options nil
   "Options used for autopep8.
 
-Note that `-' and '--exit-code' are used by default."
+Note that arguments `-' (to read form the STDIN)
+and '--exit-code' are added after any options in this list."
   :type '(repeat (string :tag "option")))
 
 (defcustom py-autopep8-on-save-p 'always
@@ -97,8 +98,14 @@ Otherwise you can set this to a user defined function."
 (defun py-autopep8--region-contract-to-whole-lines (beg end)
   "Clamp BEG & END to whole lines."
   (declare (important-return-value t))
-  (let ((beg-bol (pos-bol beg))
-        (end-eol (pos-eol end)))
+  (let ((beg-bol
+         (save-excursion
+           (goto-char beg)
+           (pos-bol)))
+        (end-eol
+         (save-excursion
+           (goto-char end)
+           (pos-eol))))
 
     ;; If the leading/trailing parts of the beginning/end lines is white-space
     ;; then extend the selection to the bounds, otherwise contract the range
@@ -157,7 +164,7 @@ Useful for fast operation, especially for automated conversion or tests."
 (defun py-autopep8--buffer-format-impl (range stdout-buffer stderr-buffer)
   "Format current buffer using temporary STDOUT-BUFFER and STDERR-BUFFER.
 When RANGE is non-nil it's used as the range to format.
-Return non-nil when a the buffer was modified."
+Return non-nil if the buffer was modified."
   (declare (important-return-value t))
   (unless (executable-find py-autopep8-command)
     (user-error "py-autopep8: %s command not found" py-autopep8-command))
@@ -173,7 +180,13 @@ Return non-nil when a the buffer was modified."
         ;; Set this for `make-process' as there are no files for autopep8
         ;; to use to detect where to read local configuration from,
         ;; it's important the current directory is used to look this up.
-        (default-directory (file-name-directory (buffer-file-name))))
+        (default-directory
+         (let ((file-name (buffer-file-name)))
+           (cond
+            (file-name
+             (file-name-directory file-name))
+            (t
+             default-directory)))))
 
     ;; Support for formatting a limited range.
     (when range
@@ -200,7 +213,7 @@ Return non-nil when a the buffer was modified."
             :sentinel (lambda (_proc _msg) (incf sentinel-called))))
           (proc-err (get-buffer-process stderr-buffer)))
 
-      ;; Unfortunately a separate process is set for the STDERR which uses it's own sentinel.
+      ;; Unfortunately a separate process is set for the STDERR which uses its own sentinel.
       ;; Needed to override the "Process .. finished" message.
       (unless (eq proc-out proc-err)
         (setq sentinel-called-expect 2)
@@ -242,7 +255,7 @@ Return non-nil when a the buffer was modified."
 (defun py-autopep8--buffer-format (range)
   "Format the current buffer.
 When RANGE is non-nil it's used as the range to format.
-Return non-nil when a the buffer was modified."
+Return non-nil if the buffer was modified."
   (declare (important-return-value nil))
   (let ((stdout-buffer nil)
         (stderr-buffer nil)
@@ -257,10 +270,9 @@ Return non-nil when a the buffer was modified."
 (defun py-autopep8--buffer-format-for-save-hook ()
   "Callback for `before-save-hook'."
   (declare (important-return-value nil))
-  ;; Demote errors as this is user configurable, we can't be sure it wont error.
-  (when (or (eq py-autopep8-on-save-p 'always) ; Keep explicit check until Emacs 26.3 is dropped.
-            (with-demoted-errors "py-autopep8: Error %S"
-              (funcall py-autopep8-on-save-p)))
+  ;; Demote errors as this is user configurable, we can't be sure it won't error.
+  (when (with-demoted-errors "py-autopep8: Error %S"
+          (funcall py-autopep8-on-save-p))
     (py-autopep8--buffer-format nil))
   ;; Always return nil, continue to save.
   nil)
@@ -284,13 +296,9 @@ Return non-nil when a the buffer was modified."
 
 (defun py-autopep8-check-pyproject-exists ()
   "Return t when a pyproject.toml file is found."
-  (declare (important-return-value nil))
+  (declare (important-return-value t))
   (let ((project-file (py-autopep8--locate-dominating-file-from-buffer "pyproject.toml")))
-    (cond
-     (project-file
-      t)
-     (t
-      nil))))
+    (and project-file t)))
 
 (defun py-autopep8-check-pyproject-exists-with-autopep8 ()
   "Return t when a pyproject.toml file is found with a tool.autopep8 entry."
@@ -315,7 +323,7 @@ Return non-nil when a the buffer was modified."
 ;;;###autoload
 (defun py-autopep8-buffer ()
   "Use the \"autopep8\" tool to reformat the current buffer.
-Return non-nil when a the buffer was modified."
+Return non-nil if the buffer was modified."
   (declare (important-return-value nil))
   (interactive "*")
   (py-autopep8--buffer-format nil))
@@ -323,7 +331,7 @@ Return non-nil when a the buffer was modified."
 ;;;###autoload
 (defun py-autopep8-region (beg end)
   "Use the \"autopep8\" tool to reformat whole lines in the region (BEG, END).
-Return non-nil when a the buffer was modified."
+Return non-nil if the buffer was modified."
   (declare (important-return-value nil))
   (interactive "*r")
   (py-autopep8--buffer-format (cons beg end)))
